# tinytext

[![PyPI version](https://img.shields.io/pypi/v/tinytext.svg?logo=pypi&logoColor=FFE873)](https://pypi.org/project/tinytext)
[![Supported Python versions](https://img.shields.io/pypi/pyversions/tinytext.svg?logo=python&logoColor=FFE873)](https://pypi.org/project/tinytext)
[![PyPI downloads](https://img.shields.io/pypi/dm/tinytext.svg)](https://pypistats.org/packages/tinytext)
[![GitHub Actions status](https://github.com/hugovk/tinytext/workflows/Test/badge.svg)](https://github.com/hugovk/tinytext/actions)
[![Codecov](https://codecov.io/gh/hugovk/tinytext/branch/main/graph/badge.svg)](https://codecov.io/gh/hugovk/tinytext)
[![Licence](https://img.shields.io/github/license/hugovk/tinytext.svg)](LICENSE.txt)
[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.4071428.svg)](https://doi.org/10.5281/zenodo.4071428)
[![Code style: Black](https://img.shields.io/badge/code%20style-Black-000000.svg)](https://github.com/psf/black)

Convert your text ᶦᶰᵗᵒ ᵗᶦᶰᶦᵉʳ ᵗᵉˣᵗ

Helpful for all your tiny cute needs.

Especially helpful for cute bot needs.

A Python port of
[Rachel White's tiny-text for Node](https://github.com/rachelnicole/tiny-text).

## How to use

Install the package into your lovely codebase.

```bash
pip install tinytext
```

```python
from tinytext import tinytext

print(tinytext("hello friend"))
```

Or on the command line:

```console
$ tinytext "hello friend"
ʰᵉᶫᶫᵒ ᶠʳᶦᵉᶰᵈ
```

And that's it!
